/***
 * Excerpted from "Simplifying JavaScript",
 * published by The Pragmatic Bookshelf.
 * Copyrights apply to this code. It may not be used to create training material,
 * courses, books, articles, and the like. Contact us if you are in doubt.
 * We make no guarantees that this code is fit for any purpose.
 * Visit http://www.pragmaticprogrammer.com/titles/es6tips for more book information.
***/
import expect from 'expect';

import {
  Validator as ValidatorProblem,
} from './problem';

import { Validator } from './bind';

import {
  Validator as ValidatorArrow,
} from './constructorArrow';

import {
  Validator as ValidatorConstructor,
} from './constructor';

import {
  Validator as ValidatorProperties,
} from './properties';

describe('Validator', () => {
  it('should not bind to this', () => {
    try {
      const validator = new ValidatorProblem();
      validator.setInvalidMessages('city');
      // TypeError: Cannot read property 'message' of undefined
    } catch (e) {
      expect(e.message).toEqual("Cannot read property 'message' of undefined");
    }
  });

  it('should bind methods in map function', () => {
    const v = new Validator();
    const message = 'city is invalid.';
    expect(v.setInvalidMessages('city')).toEqual([message]);
  });

  it('should use arrow methods in constructor', () => {
    const v = new ValidatorArrow();
    const message = 'city is invalid.';
    expect(v.setInvalidMessages('city')).toEqual([message]);
  });

  it('should bind methods in constructor', () => {
    const v = new ValidatorConstructor();
    const message = 'city is invalid.';
    expect(v.setInvalidMessages('city')).toEqual([message]);
  });

  it('should have private properties', () => {
    const v = new ValidatorProperties();
    expect(v.message).toEqual('is invalid.');
  });

  it('should bind this with arrow functions', () => {
    const v = new ValidatorProperties();
    const message = 'city is invalid.';
    expect(v.setInvalidMessages('city')).toEqual([message]);
  });
});
