/***
 * Excerpted from "Simplifying JavaScript",
 * published by The Pragmatic Bookshelf.
 * Copyrights apply to this code. It may not be used to create training material,
 * courses, books, articles, and the like. Contact us if you are in doubt.
 * We make no guarantees that this code is fit for any purpose.
 * Visit http://www.pragmaticprogrammer.com/titles/es6tips for more book information.
***/
/* eslint-disable no-console, no-unused-vars, no-param-reassign */
const fetch = require('node-fetch');


const example =
{
  userId: 1,
  id: 1,
  title: 'First Post',
  body: 'This is my first post...',
};

fetch('https://jsonplaceholder.typicode.com/posts/1');

fetch('https://jsonplaceholder.typicode.com/posts/1')
  .then(data => {
    return data.json();
  })
  .then(post => {
    console.log(post.title);
  });

fetch('https://jsonplaceholder.typicode.com/pots/1')
  .then(data => {
    if (!data.ok) {
      throw Error(data.status);
    }
    return data.json();
  })
  .then(post => {
    console.log(post.title);
  })
  .catch(e => {
    console.log(e);
  });

const update = {
  title: 'Clarence White Techniques',
  body: 'Amazing',
  userId: 1,
};

const options = {
  method: 'POST',
  headers: {
    'Content-Type': 'application/json',
  },
  body: JSON.stringify(update),
};

fetch('https://jsonplaceholder.typicode.com/posts', options).then(data => {
  if (!data.ok) {
    throw Error(data.status);
  }
  return data.json();
}).then(update => {
  console.log(update);
  // {
  //   title: 'Clarence White Techniques',
  //   body: 'Amazing',
  //   userId: 1,
  //   id: 101
  // };
}).catch(e => {
  console.log(e);
});

function getPosts() {
  return fetch('https://jsonplaceholder.typicode.com/posts')
    .then(d => {
      return d.json();
    });
}

function setLatestPost(element, retrievePosts) {
  return retrievePosts()
    .then(posts => {
      console.log(posts);
      element.innerHTML = posts[0].title;
    });
}

export { setLatestPost };
