/***
 * Excerpted from "Simplifying JavaScript",
 * published by The Pragmatic Bookshelf.
 * Copyrights apply to this code. It may not be used to create training material,
 * courses, books, articles, and the like. Contact us if you are in doubt.
 * We make no guarantees that this code is fit for any purpose.
 * Visit http://www.pragmaticprogrammer.com/titles/es6tips for more book information.
***/
import expect from 'expect';
import { failMusic, failUserPreference, getArtist, getMusic, getUserPreferences } from './promises';
import {
  getUserPreferences as prefProblem,
} from './problem';

describe('promises', () => {
  it('should resolve with data', done => {
    return prefProblem(data => {
      expect(data.theme.toUpperCase()).toEqual('DUSK');
      done();
    });
  });

  it('should resolve with data', () => {
    return getUserPreferences().then(data => {
      expect(data.theme).toEqual('dusk');
    });
  });
  it('should fail', () => {
    return failUserPreference()
      .catch(data => {
        expect(data.type).toEqual('Access Denied');
      });
  });
  it('should chain success', () => {
    return getUserPreferences()
      .then(preference => {
        return getMusic(preference.theme);
      })
      .then(music => {
        expect(music.album).toEqual('music for airports');
      });
  });

  it('should catch failure', () => {
    return getUserPreferences()
      .then(preference => failMusic(preference.theme))
      .then(music => getArtist(music.album))
      .catch(e => {
        expect(e.type).toEqual('Network error');
      });
  });
});
