/***
 * Excerpted from "Simplifying JavaScript",
 * published by The Pragmatic Bookshelf.
 * Copyrights apply to this code. It may not be used to create training material,
 * courses, books, articles, and the like. Contact us if you are in doubt.
 * We make no guarantees that this code is fit for any purpose.
 * Visit http://www.pragmaticprogrammer.com/titles/es6tips for more book information.
***/
import expect from 'expect';

import sinon from 'sinon';
import * as routing from './routing';
import * as taxService from './taxService';
import { formatPrice } from './problem';

describe('format price', () => {
  const userElement = {
    innerHTML: 'Aaron Cometbus',
  };

  const totalElement = {
    innerHTML: '',
  };

  const document = { 
    getElementById: id => {
      if (id === 'user') {
        return userElement;
      }
      if (id === 'total') {
        return totalElement;
      }
      return null;
    },
  };

  global.document = document;

  let taxStub;

  beforeEach(() => {
    taxStub = sinon.stub(taxService, 'getTaxInformation'); 
  });

  afterEach(() => {
    totalElement.innerHTML = ''; 
    taxStub.restore();
  });

  it('should redirect if no location', () => {
    sinon.spy(routing, 'redirect'); 
    formatPrice({}, undefined);
    expect(routing.redirect.called).toEqual(true);
  });

  it('should return plus tax if no tax info', () => {
    taxStub.returns(null); 
    formatPrice({ price: 30, location: 'Oklahoma' });
    const message = 'Aaron Cometbus your total is: 30 plus tax.';
    expect(totalElement.innerHTML).toEqual(message);
  });

  it('should return plus tax information', () => {
    taxStub.returns(0.1);
    formatPrice({ price: 30, location: 'Oklahoma' });
    const message = 'Aaron Cometbus your total is: 30 plus $3 in taxes.';
    expect(totalElement.innerHTML).toEqual(message);
  });
});
