/***
 * Excerpted from "Simplifying JavaScript",
 * published by The Pragmatic Bookshelf.
 * Copyrights apply to this code. It may not be used to create training material,
 * courses, books, articles, and the like. Contact us if you are in doubt.
 * We make no guarantees that this code is fit for any purpose.
 * Visit http://www.pragmaticprogrammer.com/titles/es6tips for more book information.
***/
/* eslint-disable no-unused-vars, func-names */

// Courtesy of Eric Elliot: https://twitter.com/_ericelliott/status/879356131633762305
// 
const pipe = (...fns) => x => fns.reduce((y, f) => f(y), x);
// 

// Need clever idea
function greetCity(city) {
// 
  function capitalize(word) {
    return word.split(' ')
      .map(s => s.slice(0, 1).toUpperCase() + s.slice(1))
      .join(' ');
  }

  function greet(location) {
    return `Greetings from ${location}!`;
  }

  const greetCity = pipe(capitalize, greet);

  greetCity('kansas city');
  // Greetings from Kansas City!
  // 

  return greetCity(city);
}

// 
const dogs = [
  {
    name: 'max',
    size: 'small',
    breed: 'boston terrier',
    color: 'black',
  },
  {
    name: 'don',
    size: 'large',
    breed: 'labrador',
    color: 'black',
  },
  {
    name: 'shadow',
    size: 'medium',
    breed: 'labrador',
    color: 'chocolate',
  },
];
// 

function getColors(dogs) {
// 
  const colors = dogs.reduce((colors, dog) => { 
    if (colors.includes(dog.color)) { 
      return colors;
    }
    return [...colors, dog.color]; 
  }, []); 
  // 
  return colors;
}

function getAllColors(dogs) {
// 
  const colors = dogs.reduce((colors, dog) => {
    return [...colors, dog.color];
  }, []);
  // 
  return colors;
}

function separate(dogs) {
// 
  const filters = dogs.reduce((filters, item) => {
    filters.breed.add(item.breed);
    filters.size.add(item.size);
    filters.color.add(item.color);
    return filters;
  },
  {
    breed: new Set(),
    size: new Set(),
    color: new Set(),
  });
  // 

  return filters;
}


// 
const developers = [
  {
    name: 'Jeff',
    language: 'php',
  },
  {
    name: 'Ashley',
    language: 'python',
  },
  {
    name: 'Sara',
    language: 'python',
  },
  {
    name: 'Joe',
    language: 'javascript',
  },
];
// 

function getSpecialtyCount(developers) {
// 
  const aggregated = developers.reduce((specialities, developer) => {
    const count = specialities[developer.language] || 0;
    return {
      ...specialities,
      [developer.language]: count + 1,
    };
  }, {});
  // 

  return aggregated;
}

function getExact() {
  // 
  const callback = function (collectedValues, item) { 
    return [...collectedValues, item];
  };

  const saying = ['veni', 'vedi', 'veci'];
  const initialValue = [];
  const copy = saying.reduce(callback, initialValue); 
  // 
  return copy;
}
export { developers, dogs, getAllColors, getColors, getSpecialtyCount, greetCity, separate };
